Documentation
¶
Index ¶
- type Borders
- type Colors
- type IconSet
- type Option
- type Spacing
- type Theme
- func (t Theme) Borders() Borders
- func (t Theme) Colors() Colors
- func (t Theme) HeaderStyle() lipgloss.Style
- func (t Theme) Icon(name string) string
- func (t Theme) IconSet() IconSet
- func (t Theme) PanelStyle() lipgloss.Style
- func (t Theme) PanelTitleStyle() lipgloss.Style
- func (t Theme) ProgressGradient() []string
- func (t Theme) Spacing() Spacing
- func (t Theme) StatusBarStyle() lipgloss.Style
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Colors ¶
type Colors struct {
Primary color.Color
Secondary color.Color
Accent color.Color
Background color.Color
Muted color.Color
Success color.Color
Error color.Color
}
Colors holds the shared color palette used across the TUI.
type Option ¶
type Option func(*Theme)
Option configures a Theme during construction.
func WithBorders ¶
WithBorders overrides the border configuration.
func WithColors ¶
WithColors overrides the base color palette.
func WithIconSet ¶
WithIconSet overrides the icon set used by the theme.
func WithSpacing ¶
WithSpacing overrides the default spacing values.
type Theme ¶
type Theme struct {
// contains filtered or unexported fields
}
Theme centralizes palette, border, spacing, and icon configuration.
func (Theme) HeaderStyle ¶
HeaderStyle returns the shared style used for primary headers.
func (Theme) PanelStyle ¶
PanelStyle returns the shared panel container style.
func (Theme) PanelTitleStyle ¶
PanelTitleStyle returns the shared style for panel titles.
func (Theme) ProgressGradient ¶
ProgressGradient returns the gradient colors for progress bars.
func (Theme) StatusBarStyle ¶
StatusBarStyle returns the shared style used for footer/status bars.